#!/usr/bin/env Rscript
# blastall -p tblastn -m 8 -a 8 -i toxins.fa -d genome -F F > genome_blast.out
# Rscript --vanilla ~/BinScript/BoNT_Classifier.R genome_blast.out >> all_parsed.out
# toxin protein sequnces: 
#    /nas/project/MT05_Clostridium_botulinum_2019_May/02_toxins
# or /data/Utilities/DB/
#
# Typical results
###############################################
#Processing GCA_000007625.1_blast.out...
#
#No hits found! 0% identity will be given to all 42 toxin queries.
###############################################
#Processing GCA_000017025.1_blast.out...
#max percent identity: 100.0000%
#Not a new subtype (100.00% identical to A1_CAL82360.1)
###############################################
#Processing GCA_000724345.2_blast.out...
#max percent identity: 96.1800%
#Congratulations! You found a new subtype candidate! (96.18% identical to D_EES90380.1)
###############################################

args = commandArgs(trailingOnly=TRUE)

data = read.table(args[1],sep="\t",comment.char="#",header=F)
cat(sprintf("##############################################"))
cat("\n")
cat(sprintf("Processing %s...",args[1]))
cat("\n")
#data = read.table("tblastn.out",sep="\t",comment.char="#",header=F)
d = data
d.best = do.call(rbind, lapply(split(d,d$V1), function(x) {return(x[which.max(x$V12),])}))

names(d.best) = c("query_id","subject_id","pct_identity","aln_length","n_of_mismatches","gap_openings","q_start","q_end","s_start","s_end","e_value","bit_score")

d.best.filt = d.best[(d.best$pct_identity > 85) & (d.best$aln_length) > 1100,]

if (length(row.names(d.best.filt)) != 0)
######
{
    cat(sprintf("max percent identity: %.4f%%",max(d.best.filt$pct_identity))) # new subtype if pid at most 97.4%
    cat("\n")
    temp = d.best.filt[which.max(d.best.filt$pct_identity),]
    
    if (max(d.best.filt$pct_identity) > 97.4) {
        cat(sprintf("Not a new subtype "))
        cat(sprintf("(%.2f%% identical to %s)", max(d.best.filt$pct_identity), row.names(temp)))
	cat("\n")
    } else {
        cat(sprintf("Congratulations! You found a new subtype candidate! "))
        cat(sprintf("(%.2f%% identical to %s)", max(d.best.filt$pct_identity), row.names(temp)))
	cat("\n")
    }
} else {
    cat(sprintf("\nNo hits found! 0%% identity will be given to all 42 toxin queries."))
    cat("\n")
}
######

d.out = d.best.filt[,c(1,3)]

if (length(row.names(d.out)) == 0) {
d.out = cbind( c("A1_CAL82360.1","A2_CAA51824.1","A3_ACA57525.1","A4_ACQ51417.1","A5_ACG50065.1","A6_ACW83608.1","A7_AFV13854.1","A8_AJA05787.1","B1_ACA46990.1","B2_BAC22064.1","B3_ABM73977.1","B4_ABM73987.1","B5_ACQ51206.1","B6_BAF91946.1","B7_AFD33678.1","B8_AFN61309.1","C_BAA08418.1","CD_BAA14235.1","DC_ABP48747.1","D_EES90380.1","E10_AII82330.1","E11_AII82289.1","E12_AHK10119.1","E1_CAA43999.1","E2_ABM73981.1","E3_ABM73980.1","E4_BAC05434.1","E5_BAB03512.1","E6_CAM91125.1","E7_AER11391.1","E8_AER11392.1","E9_AFV91339.1","F1_ABS41202.1","F2_CAA73972.1","F3_ADA79575.1","F4_ADA79569.1","F5_ADA79560.1","F6_AAA23263.1","F7_ADK48765.1","F8_KEJ01913.1","FA_KGO15617.1","G_KIE44899.1"), rep(0,42))
}

write.table(d.out,file=paste(args[1],".csv",sep=""),sep=",",quote=F,col.names=F,row.names=F)


# [Good!] Rscript --vanilla test.R GCF_001573245.1.fasta.tbn.out
# [Bad!] Rscript --vanilla test.R GCF_000204395.1.fasta.tbn.out
